package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`/@`!````L"5```````!``````````!BS````
M`````````$``.``-`$``'``;``8````$````0`````````!``$```````$``
M0```````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#0```````&`-````````<`````````!P``````````0`````````!````
M!`````````````````!``````````$```````/`3````````\!,`````````
M$`````````$````%`````"``````````($`````````@0```````Y3P`````
M``#E/``````````0`````````0````0`````8`````````!@0````````&!`
M``````#`1P```````,!'`````````!`````````!````!@```."M````````
MX+U```````#@O4````````@$````````>`0`````````$`````````(````&
M````\*T```````#PO4```````/"]0```````X`$```````#@`0````````@`
M````````!`````0````X`P```````#@#0```````.`-```````!`````````
M`$``````````"``````````$````!````'@#````````>`-```````!X`T``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`T```````#@#0```````0`````````!```````````@`````````4.5T9`0`
M``#@H````````."@0```````X*!```````#\`````````/P`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````X*T```````#@O4```````."]0```
M````(`(````````@`@````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````,`````4```!'3E4``H``P`0````!````````
M``$``<`$````"0`````````"``'`!`````$`````````!````!0````#````
M1TY5`)6G4T9K;147XL;>XP+^%64`$BD$!````!`````!````1TY5```````#
M`````@``````````````"0```#D````!````!@```%(+@`#``4`*.0```#H`
M```[````/````#T`````````/@```#\`````````R=6R<3GRBQR'^9R!I]VC
M:\6YG$`+BA!7>_!*:P```````````````````````````````-0````2````
M`````````````````````!X!```2`````````````````````````)T````2
M`````````````````````````#("```2``````````````````````````,"
M```2``````````````````````````$````@````````````````````````
M`&$!```2`````````````````````````(<"```2````````````````````
M`````,,!```2`````````````````````````'4"```2````````````````
M`````````#8!```2`````````````````````````&0````2````````````
M`````````````(T````2`````````````````````````)<!```2````````
M`````````````````+T!```2`````````````````````````.T````2````
M`````````````````````-T!```2`````````````````````````*T!```2
M`````````````````````````*@````2`````````````````````````-D`
M```2`````````````````````````+8!```2````````````````````````
M`!("```2`````````````````````````$`"```2````````````````````
M`````,X!```2`````````````````````````/L````2````````````````
M`````````#T!```6`````````````````````````'P````2````````````
M`````````````&T````2`````````````````````````(\!```2````````
M`````````````````(@!```2`````````````````````````-X````2````
M`````````````````````.0!```2`````````````````````````)X!```2
M`````````````````````````#D"```2`````````````````````````,8`
M```2`````````````````````````&0"```2````````````````````````
M`'@!```2`````````````````````````"$````2````````````````````
M`````%`!```2`````````````````````````%T"```2````````````````
M`````````*8!```2`````````````````````````!$"```2````````````
M`````````````$@"```2``````````````````````````D!```2````````
M`````````````````"H!```2`````````````````````````&8!```2````
M`````````````````````'\!```2`````````````````````````/4!```2
M`````````````````````````$\"```2`````````````````````````.T!
M```2`````````````````````````"T````2````````````````````````
M`$4````2`````````````````````````!D"```2````````````````````
M`````%8"```2`````````````````````````&X!```2````````````````
M`````````,@!```2`````````````````````````+,````2````@"!`````
M`````````````"L"```1`!D`(,)````````(`````````!`````2````T"%`
M`````````````````'\"```A`!D``,)````````(`````````'T"```1`!D`
M`,)````````(`````````#@````1`!D`,,)````````!`````````%0````2
M````P"%```````````````````!?7V=M;VY?<W1A<G1?7P!097)L7V%T9F]R
M:U]L;V-K`%!E<FQ?;6=?<V5T`%!E<FQ?;F5W6%,`4$Q?9&]?=6YD=6UP`%!E
M<FQ?<WES7VEN:70S`&)O;W1?1'EN84QO861E<@!P97)L7W)U;@!P97)L7V-O
M;G-T<G5C=`!097)L7VYE=UA37V9L86=S`%!E<FQ?9W9?9F5T8VAP=@!P97)L
M7W!A<G-E`'!E<FQ?86QL;V,`4&5R;%]A=&9O<FM?=6YL;V-K`'!E<FQ?9&5S
M=')U8W0`<&5R;%]F<F5E`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?<W9?<V5T<'8`
M4&5R;%]S>7-?=&5R;0!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V=E=%]S
M=@!097)L7W-A9F5S>7-M86QL;V,`4$Q?8W5R<F5N=%]C;VYT97AT`%]?<W1A
M8VM?8VAK7V9A:6P`97AI=`!L<V5E:S8T`')E861D:7(V-`!S=')D=7``8VQO
M<V5D:7(`;W!E;C8T`'-T<G)C:'(`=6YL:6YK`&UE;6UO=F4`<W1R=&]K`&=E
M='!W=6ED`'-T<FQE;@!R;61I<@!R96%D`&UK9&ER`%]?=F9P<FEN=&9?8VAK
M`&=E='!I9`!R96%D;&EN:P!R96%L;&]C`%]?<W!R:6YT9E]C:&L`7U]F<')I
M;G1F7V-H:P!L<W1A=#8T`%]?;&EB8U]S=&%R=%]M86EN`'-T9&5R<@!M96UC
M:'(`<W1R8VAR`&]P96YD:7(`9V5T=6ED`&%C8V5S<P!M96UC<'D`<W1R8VUP
M`%]?97)R;F]?;&]C871I;VX`<W1R;F-M<`!?7V5N=FER;VX`7U]R96=I<W1E
M<E]A=&9O<FL`;&EB<&5R;"YS;RXU+C,X`&QI8F,N<V\N-@!'3$E"0U\R+C$T
M`$=,24)#7S(N,S0`1TQ)0D-?,BXT`$=,24)#7S(N,S,`1TQ)0D-?,BXS+C(`
M1TQ)0D-?,BXS+C0`1TQ)0D-?,BXR+C4````!``$``0`"``,``0`"``0``@`"
M``(``0`!``(``@`!``(``@`!``(``@`%``(``P`!``$``0`!``(``@`!``(`
M`@`"``$``@`"``$`!@`"``(`!0`"``$``0`"``(``P`"``(``0`!``<`"``"
M``(``0`"``$``@`"``$``0`````````!``<`J0(``!``````````E)&6!@``
M"`"S`@``$````+21E@8```<`O@(``!`````4:6D-```&`,D"```0````LY&6
M!@``!0#3`@``$````'(9:0D```0`W@(``!````!T&6D)```#`.H"```0````
M=1II"0```@#V`@```````-"_0```````!@````8``````````````-B_0```
M````$@```!H``````````````."_0```````!@```#4```````````````#"
M0```````!0```#T``````````````"#"0```````!0```#H`````````````
M`##"0```````!0```#X```````````````#`0```````!P````$`````````
M``````C`0```````!P````(``````````````!#`0```````!P````,`````
M`````````!C`0```````!P````0``````````````"#`0```````!P````4`
M`````````````"C`0```````!P```#D``````````````##`0```````!P``
M``<``````````````#C`0```````!P````@``````````````$#`0```````
M!P````D``````````````$C`0```````!P````H``````````````%#`0```
M````!P````L``````````````%C`0```````!P````P``````````````&#`
M0```````!P````T``````````````&C`0```````!P````X`````````````
M`'#`0```````!P````\``````````````'C`0```````!P```!``````````
M`````(#`0```````!P```!$``````````````(C`0```````!P```!(`````
M`````````)#`0```````!P```!,``````````````)C`0```````!P```!0`
M`````````````*#`0```````!P```!4``````````````*C`0```````!P``
M`!8``````````````+#`0```````!P```!<``````````````+C`0```````
M!P```!@``````````````,#`0```````!P```!D``````````````,C`0```
M````!P```#\``````````````-#`0```````!P```#L``````````````-C`
M0```````!P```!L``````````````.#`0```````!P```!P`````````````
M`.C`0```````!P```!T``````````````/#`0```````!P```!X`````````
M`````/C`0```````!P```!\```````````````#!0```````!P```"``````
M``````````C!0```````!P```"$``````````````!#!0```````!P```"(`
M`````````````!C!0```````!P```",``````````````"#!0```````!P``
M`"0``````````````"C!0```````!P```"4``````````````##!0```````
M!P```"8``````````````#C!0```````!P```"<``````````````$#!0```
M````!P```"@``````````````$C!0```````!P```"D``````````````%#!
M0```````!P```"H``````````````%C!0```````!P```"L`````````````
M`&#!0```````!P```"P``````````````&C!0```````!P```"T`````````
M`````'#!0```````!P```"X``````````````'C!0```````!P```"\`````
M`````````(#!0```````!P```#```````````````(C!0```````!P```#$`
M`````````````)#!0```````!P```#(``````````````)C!0```````!P``
M`#,``````````````*#!0```````!P```#0``````````````*C!0```````
M!P```#8``````````````+#!0```````!P```#<``````````````+C!0```
M````!P```#@`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!(@^P(2(L%Q9\``$B%P'0"_]!(@\0(PP```````````/\URI\``/\ES)\`
M``\?0`#_)<J?``!H`````.G@_____R7"GP``:`$```#IT/____\ENI\``&@"
M````Z<#_____);*?``!H`P```.FP_____R6JGP``:`0```#IH/____\EHI\`
M`&@%````Z9#_____)9J?``!H!@```.F`_____R62GP``:`<```#I</____\E
MBI\``&@(````Z6#_____)8*?``!H"0```.E0_____R5ZGP``:`H```#I0/__
M__\E<I\``&@+````Z3#_____)6J?``!H#````.D@_____R5BGP``:`T```#I
M$/____\E6I\``&@.````Z0#_____)5*?``!H#P```.GP_O___R5*GP``:!``
M``#IX/[___\E0I\``&@1````Z=#^____)3J?``!H$@```.G`_O___R4RGP``
M:!,```#IL/[___\E*I\``&@4````Z:#^____)2*?``!H%0```.F0_O___R4:
MGP``:!8```#I@/[___\E$I\``&@7````Z7#^____)0J?``!H&````.E@_O__
M_R4"GP``:!D```#I4/[___\E^IX``&@:````Z4#^____)?*>``!H&P```.DP
M_O___R7JG@``:!P```#I(/[___\EXIX``&@=````Z1#^____)=J>``!H'@``
M`.D`_O___R72G@``:!\```#I\/W___\ERIX``&@@````Z>#]____)<*>``!H
M(0```.G0_?___R6ZG@``:"(```#IP/W___\ELIX``&@C````Z;#]____):J>
M``!H)````.F@_?___R6BG@``:"4```#ID/W___\EFIX``&@F````Z8#]____
M)9*>``!H)P```.EP_?___R6*G@``:"@```#I8/W___\E@IX``&@I````Z5#]
M____)7J>``!H*@```.E`_?___R5RG@``:"L```#I,/W___\E:IX``&@L````
MZ2#]____)6*>``!H+0```.D0_?___R5:G@``:"X```#I`/W___\E4IX``&@O
M````Z?#\____)4J>``!H,````.G@_/___R5"G@``:#$```#IT/S___\E.IX`
M`&@R````Z<#\____)3*>``!H,P```.FP_/___R4JG@``:#0```#IH/S___\E
M(IX``&@U````Z9#\____)1J>``!H-@```.F`_/___R42G@``:#<```#I</S_
M_U-(@^PPB7PD'$B-?"0<2(ET)!!(C70D$$B)5"0(2(U4)`AD2(L$)2@```!(
MB40D*#'`Z(G___^Z@"!``+_0(4``2(G6Z-<X``"`/3">````#X0*`0``2(L%
MRYL``&1(BP"`B#H$```#BT0D'(UX!(U8`TAC_TC!YP/HTO[__TB+?"001(M$
M)!Q(B<%(B04&G@``2(L'2,=!".=A0`!(QT$8ZF%``$B)`4B+!8&=``!(B4$0
M08/X`0^.'@$``$B#QPA!@\`#N@0```!F#Q]$``!(BP=(8_*#P@%(@\<(2(D$
M\40YPG7J2&/22(L]L)T``$4QP+Z`+$``2,<$T0````")VNB9^___A<`/A($`
M``!(BSV*G0``Z)7]__](C70D)+^C8$``B<,QP.C"`0``2(7`=&Y(BSUFG0``
MZ$'[___HO/S__TB+1"0H9$@K!"4H````#X67````2(/$,(G86\/H._S__TB)
M!32=``!(B<=(A<!T<>C'_/__2(L%J)H``&1(BQ#&@BX)````Z<W^__](BST)
MG0``Z)3[___I;O___TB+/>B<``!(A?]T"NCN&P``Z7S___^_6&!``$B-="0D
MZ"H!``!(B07#G```2(G'2(7`#X1:____Z]*Z!````.D!____OP$```#H\?K_
M_^C\_/__9BX/'X0``````&:0,>U)B=%>2(GB2(/D\%!413'`,<E(Q\>P(T``
M_Q4/F@``]&8N#Q^$```````/'T``PV8N#Q^$```````/'T0``+CHP4``2#WH
MP4``=!.X`````$B%P'0)O^C!0`#_X&:0PV9F+@\?A```````#Q]``+[HP4``
M2('NZ,%``$B)\$C![C](P?@#2`'&2-'^=!&X`````$B%P'0'O^C!0`#_X,-F
M9BX/'X0```````\?0`#S#Q[Z@#W&FP```'4354B)Y>AZ____Q@6TFP```5W#
MD,-F9BX/'X0```````\?0`#S#Q[ZZXIF+@\?A```````05=!5D%505154TB#
M[`A(A?\/A+$```!,BS5"FP``387V#X2A````#[8'28G_28GUA,!T!#P]=5A%
M,>1)BQY(A=MT,TUCY$R)]0\?@`````!,B>),B?Y(B=_HPOG__X7`=0="@#PC
M/71'2(M="$B#Q0A(A=MUVDB#Q`A(B=A;74%<05U!7D%?PP\?A```````28G\
M00^V1"0!28/$`83`=`0\/77N12G\ZY%F#Q]$``!,*?5*C5PC`4C!_0-!B6T`
MZ[1F#Q]$```QV^NJ#Q]``%-(B?M(@>R@````9$B+!"4H````2(F$))@````Q
MP$B)YN@Z^___A<!U-HM4)!B!X@#P``"!^@!```!T"('Z`*```'4>O@(```!(
MB=_H?_O__X7`#Y3`#[;`ZP</'T0``#'`2(N4))@```!D2"L4)2@```!U"4B!
MQ*````!;P^BM^O__9F8N#Q^$``````!FD$%505154TB![*@```!D2(L$)2@`
M``!(B80DF````#'`2(7_=`B`/P!(B?MU*TB+A"28````9$@K!"4H````#X4;
M`0``2('$J````%M=05Q!7<-F#Q]$``#H,_G__TF)Q$B%P'3(3(GGZ"/[__](
MA<`/A*H```"`>!,N2(UH$W40@'T!`'3?9BX/'X0``````(!X$RX/A)X```!(
MB=_HSOC__TB)[TF)Q>C#^/__08U\!0)(8__H%OC__TF)Z4F)V+D$8$``28G%
M2(G'O@$````QP$C'PO_____H4OK__TR)[TB)YNB7^/__3(GO@_C_=!"+1"08
M)0#P```]`$```'17Z/KW__],B>_H4OC__TR)Y^AZ^O__2(7`#X57____D$R)
MY^CX^?__2(G?Z.#W___I^/[__P\?`(!]`2X/A5C___^`?0(`#X09____Z4G_
M__\/'X``````Z*/^___KI^@\^?__9F8N#Q^$``````"0052Z_P\``%5(B?53
M2(G[OPI@0`!(@>P0$```9$B+!"4H````2(F$)`@0```QP$B)YNB*^/__A<!^
M$HG!@^@!2&/0@#P4`'5(A<!U/$B+!166``!(B>I(B=YD2(LXZ$[W__](BX0D
M"!```&1(*P0E*````'5.2('$$!```%M=05S##Q^``````(G!9@\?1```3&/A
MOB\```!(B>=,B>+H3?;__TB%P'2D2(L%N94``$R)X4B)XDB)WF1(BSCH[_?_
M_^N?Z&CX__\/'X0``````$%7059!54%454B)]5-(B?M(@^P89$B+!"4H````
M2(E$)`@QP#'`@#X]#Y3`2`'%2(GOZ/GV__](C70D!$B)WTF)Q#'`Z!?\__](
MA<`/A`8!``!(B<=)B<7HT_;__TPYX`^#T@```$QC="0$2<'F`P^V`X3`#X2>
M`0``/#T/A)8!``!(B=@/'P`/ME`!2(/``832=`6`^CUU[T@IV$B83(LM&Y<`
M`$J-?"`"Z.'U__]-`?5)B44`2(7`=%9(BP7^E@``2(U+`4J+%#`/M@.(`H3`
M="(\/74-ZQP/'X``````A,!T$0^V`4B#P@%(@\$!B`(\/77KQ@(],<!F#Q]$
M```/MDP%`(A,`@%(@\`!A,EU[TB+1"0(9$@K!"4H````#X4'`0``2(/$&%M=
M05Q!74%>05_##Q]``#'`9@\?1```#[94!0!!B%0%`$B#P`&$TG7NZ[T/'T``
M3(L]898``$F#/P`/A+8```!,B?A%,>V02(/`"$2)ZD&#Q0%(@S@`=>^-<@-(
M8_9(P>8#BP5GE@``A<!U6\<%698```$```!(B??HZ?3__TB%P`^$8?___TUC
M]4R)_DB)QTG!Y@-,B?+H._;__TB)!?25``!(B<%!C44!1(EL)`1(F$C'!,$`
M````Z8C^__]F#Q^$``````!,B?_H&/?__TB)!<&5``!(B<%(A<`/A`;___]-
M8_5)P>8#Z[L/'T``,<#I?_[__[X0````13'MZ5_____H+_;__V9F+@\?A```
M````#Q]``%.Y<*!``+K`(4``OAE@0`!(BQU!DP``9$B+.^C`]O__9$B+.T4Q
MR5M!N,1A0`"Z4#]``+XU8$``3(G!Z2#U__^Y<*!``+K`(4``OAE@0`!(BP4"
MDP``9$B+..F!]O__D%-(@>P@(```9$B+!"4H````2(F$)!@@```QP.@P]/__
MN@$0``"^`0```$B)YT&)P$&Y%6!``#'`N4I@0`#H#O;__[H`$```2(VT)!`0
M``!(B>?H^?3__X7`>%2->`%(B<-(8__HA_/__TB%P'1!2&/;2(VT)!`0``!(
MB<=(B=KH'/;__\8$&`!(B<%(BX0D&"```&1(*P0E*````'4,2('$("```$B)
MR%O#Z!'U__\QR>O89F8N#Q^$``````!FD.D[____9F8N#Q^$``````!!54%4
M28G\OUA@0`!54TB)\TB![+@0``!D2(L$)2@```!(B80DJ!```#'`2(UT)`SH
MN_C__[XO````3(GG2(G%Z%OT__](A<!T/C'`3(GFOV%@0`#H-_S__TR)X$B+
ME"2H$```9$@K%"4H````#X6'`0``2('$N!```%M=05Q!7<,/'X``````2(G?
MZ$#T__^^;F!``$B)Q^AS]/__2(G#2(7`=*6`.P`/A-T```!FD$B%[7032(G>
M2(GOZ$#T__^%P`^$H@```$B)W^CP\O__2(U4`_])B<5(.=-R#^L=D,8"`$B#
MZ@%(.=-T!8`Z+W3O2(G?Z,?R__])B<5,B>?HO/+__TF-1`4!2#W_#P``#X<U
M____2(/L"+ET84``N@`0```QP$%40;EP8$``28G8O@$```!(C;PDL````.@^
M]/__2(UT)"!(C;PDL````.A\\O__6EF%P'40BT0D*"4`\```/0"```!T5KYN
M8$``,?_HFO/__TB)PTB%P`^$R/[__X`[``^%)?___TB%[70&@'T`+G0:0;T!
M````NU9@0`#I5O___V8N#Q^$``````"`?0$`=+3KW@\?A```````O@$```!(
MC;PDH````.B^\___A<!UE$B-M"2@````OV%@0`#HJ/K__TB-O"2@````Z-OR
M___I8O[__^CQ\O__D%.^+P```$B)^^A"\O__2(U0`4B%P$@/1=I(B=];Z:[R
M__]F9BX/'X0```````\?`%532('L&!```&1(BP0E*````$B)A"0($```,<!(
MA?\/A,L```"`/P!(B?L/A+\```#H6O'__TB-4`%(@?H`$```#X?A````2(GE
M2(GO@_H(<@Z)T4B)WL'I`_-(I4B)\S')]L($=`F+"XD/N00```#VP@)T#D0/
MMP0+9D2)!`](@\$"@^(!=`</MA0+B!0/2(U$!?](.<5R$^L6#Q]$``#&``!(
M@^@!2#GH=`6`."]T[[XO````2(GOZ&+Q__](A<!T+4@YQ7)82(GOZ-#Q__](
MBY0D"!```&1(*Q0E*````'5)2('$&!```%M=PP\?`$B+A"0($```9$@K!"4H
M````=2E(@<08$```OU9@0`!;7>F*\?__9BX/'X0``````,8``.NC#Q\`,<#K
MI.B/\?__9F8N#Q^$```````/'T``2(/L&&1(BP0E*````$B)1"0(,<`/'T``
M,<!(C70D!+]R8$``Z%?U__](A<!T.DAC5"0$2(L%II```$B-!-!(BU`(2(D0
M2(72=,YF#Q]$``!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$```QP$B-="0$OWM@
M0`#H!_7__TB%P'0Z2&-4)`1(BP56D```2(T$T$B+4`A(B1!(A=)TSF8/'T0`
M`$B+4!!(@\`(2(D02(72=?#KMF8/'T0``#'`2(UT)`2_@V!``.BW]/__2(7`
M=#I(8U0D!$B+!0:0``!(C0302(M0"$B)$$B%TG3.9@\?1```2(M0$$B#P`A(
MB1!(A=)U\.NV9@\?1```,<!(C70D!+^,8$``Z&?T__](A<!T.DAC5"0$2(L%
MMH\``$B-!-!(BU`(2(D02(72=,YF#Q]$``!(BU`02(/`"$B)$$B%TG7PZ[9F
M#Q]$```QP$B-="0$OY-@0`#H%_3__TB%P'0Z2&-4)`1(BP5FCP``2(T$T$B+
M4`A(B1!(A=)TSF8/'T0``$B+4!!(@\`(2(D02(72=?#KMF8/'T0``#'`2(UT
M)`2_HV!``.C'\___2(7`=#I(8U0D!$B+!1:/``!(C0302(M0"$B)$$B%TG3.
M9@\?1```2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```,<!(C70D!+]88$``Z'?S
M__](A<!T.DAC5"0$2(L%QHX``$B-!-!(BU`(2(D02(72=,YF#Q]$``!(BU`0
M2(/`"$B)$$B%TG7PZ[9F#Q]$```QP$B-="0$OZ]@0`#H)_/__TB%P'0Z2&-4
M)`1(BP5VC@``2(T$T$B+4`A(B1!(A=)TSF8/'T0``$B+4!!(@\`(2(D02(72
M=?#KMF8/'T0``#'`2(UT)`2_N6!``.C7\O__2(7`=#I(8U0D!$B+!2:.``!(
MC0302(M0"$B)$$B%TG3.9@\?1```2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```
M,<!(C70D!+_#8$``Z(?R__](A<!T.DAC5"0$2(L%UHT``$B-!-!(BU`(2(D0
M2(72=,YF#Q]$``!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$```QP$B-="0$OV%@
M0`#H-_+__TB%P'0Z2&-4)`1(BP6&C0``2(T$T$B+4`A(B1!(A=)TSF8/'T0`
M`$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$B-="0$O\U@0`#HZ?'__TB%P'0/
M2(G&O[E@0``QP.AU]?__,<!(C70D!+_>8$``Z,3Q__](A<!T#TB)QK_P8$``
M,<#H4/7__TB-="0$O_M@0``QP.B?\?__2(G&2(7`=#&_6&!``#'`Z"OU__](
MBT0D"&1(*P0E*````'4\OAQA0`"_DV!``#'`2(/$&.D&]?__,<!(C70D!+\+
M84``Z%7Q__](A<!TQ4B)QK^O8$``,<#HX?3__^NTZ#KM__]F+@\?A```````
M2(/L&+^O8$``9$B+!"4H````2(E$)`@QP$B-="0$Z`WQ__](A<!T,`^V$(#Z
M,`^4P(32#Y3""="#\`$/ML!(BU0D"&1(*Q0E*````'4.2(/$&,,/'T0``#'`
MZ^+HS^S__V9F+@\?A```````#Q]``$B![-@```!(B70D*$B)5"0P2(E,)#A,
MB40D0$R)3"1(A,!T-P\I1"10#RE,)&`/*50D<`\IG"2`````#RFD))`````/
M*:PDH`````\IM"2P````#RF\),````!D2(L$)2@```!(B40D&#'`2(GZ2(V$
M).````!(B>%(BSW`BP``2(E$)`B^`0```$B-1"0@QP0D"````,=$)`0P````
M2(E$)!#H&.O__[__````Z/[I__]F9BX/'X0```````\?`$%4N@(````Q]D&)
M_%532('L$``!`&1(BP0E*````$B)A"0(``$`,<!(B>/H0.S__TB-:/](B>I(
MP?H_2,'J,$B-1!4`#[?`2"G02"G%#XBA````#Q]$```QTDB)[D2)Y^@+[/__
M2(/X_P^$F@```+H(``$`2(G>1(GGZ)'I__^#^/]T>4B82(/X!W942(U$`_A(
M.=AS$^M(#Q^$``````!(@^@!2#G8<C=(BPV`B@``2#D(=>M(*=A(`>A(BY0D
M"``!`&1(*Q0E*````'5'2('$$``!`%M=05S#9@\?1```2('M```!`$B!_0``
M__\/A63___](Q\#_____Z[Z_*V%``#'`Z#?^__^_'F%``#'`Z"O^___HYNK_
M_V8/'T0``$B#[`CH%^O__XG'Z'#I__](A<!T`TB+`$B#Q`C##Q\`05152(G]
MOS=A0`!32(/L$&1(BP0E*````$B)1"0(,<!(C70D!.B6[O__2(7`=`B`.`!(
MB<-U*4B+1"0(9$@K!"4H````=7E(B>Y(@\00OS=A0``QP%M=05SI`O+__V:0
M2(GOZ"CI__](B=])B<3H'>G__TF-?`0"Z'/H__](@^P(28GHN71A0`!32,?"
M_____TB)QTF)Q$&Y;F!``+X!````,<#HI^K__UA:2(M$)`AD2"L$)2@```!U
M!4R)YNN*Z/OI__]F9BX/'X0``````$%7059!54%454B)_;]88$``4TB![&@!
M``!D2(L$)2@```!(B80D6`$``+A.84``2(UT)`Q(QT0D(`````!(QT0D>```
M``!(QT0D0`````!F2`]NP+CI8$``#Q8%<&<```\I1"009D@/;L"X!F%```\6
M!6)G```/$40D6&9(#V[`N%]A0``/%@549P``#Q%$)&AF2`]NP#'`#Q8%26<`
M``\I1"0PZ$?M__](A<!T#(`X`$B)PP^%1@0``.AQZ?__B<?HRN?__TB%P`^$
MP0,``$B+&$B%VP^$M0,``$B)W^C=Y___2(U\``'H,^?__T0/M@-)B<5)B<1%
MA,!T-`\?0`!%#[;`3(GON6UA0``QP$C'PO____^^`0```$B#PP%)@\4"Z%GI
M__]$#[8#183`==!,C6PD6+_P8$``ZQ$/'T``28M]`$F#Q0A(A?]T.TB-="0,
M,<#HE^S__TB)PTB%P'3?@#@`=-I(B<?H4NW__X7`=,Y(B=_H5NC__TB)PTB%
MP'4^9@\?1```3(UL)!!)BUT`2(7;="J`.P`/A.$"``!(B=_H&>W__X7`#X7Q
M````28M="$F#Q0A(A=MUV@\?0`!(B=_H^.;__TR)YTF)Q>CMYO__18VT!00$
M``!-8_9,B??H.N;__T%428G80;EP8$``:'MA0`!(B<=)B<6Y<F%``$C'PO__
M__^^`0```#'`Z&SH__],B>^^P`$``.C/Z/__7T%8@_C_=1+HDN?__T2+"$&#
M^1$/A:$"``!(C;0D@````$R)[^C5Y___B<.%P'1O2(M-`$B+/12'``!-B>@Q
MP+HP8D``O@$```#H4.7__T4QY$B+A"18`0``9$@K!"4H````#X7W`P``2('$
M:`$``$R)X%M=05Q!74%>05_#D$B)WTF#Q0CH).?__TB)PTB%P`^$U?[__^D#
M____#Q\`BX0DF````"4`\```/0!````/A7K___]$BZ0DG````.A,Y___03G$
M#X5D____BX0DF````"7_`0``/<`!```/A4W___],B??H%.7__TB-="0,OT)A
M0`!)B<0QP.C0ZO__2(7`#X0W`@``2(M]`$B)QNC+\?__28G'2(7`#X0?`@``
M3(G_Z'?E__])B<:#^`-^-TB8OH!A0`!)C7P'_.B>YO__A<!U(D&#_@0/A-@"
M``!!C4;[2)A!@#P'+P^$QP(```\?@``````QP$B-="0,OZ]@0`#H5^K__TB%
MP`^$S@$```^V`(3`#X3#`0``/#`/A+L!``"^'&%``+^O8$``,<#HRNW__^BU
MY/__:,1A0`!-B>A,B>=02,?"_____T&Y<&!``#'`N:1A0`"^`0```.B+YO__
M6%KK3`\?@`````#HN^7__X,X$75-Z''D__^#PP%(@^P(38GH:,1A0`!!N7!@
M0`!,B>>YLF%``%-(Q\+_____O@$```!0,<#H/^;__TB#Q""^P`$``$R)Y^B>
MYO__@_C_=*E,B>_H4>3__TR)YK]88$``,<#H(NW__TR)Y^BZ^O__Z?C]__\/
M'T0``#';Z3G]__]F#Q^$``````!,C60D,.L-9@\?A```````28/$"$F+/"1(
MA?\/A(<````QP$B-="0,Z#/I__](A<!TWH`X`'392(G'Z`'E__](B<-(A<!T
MR>G_^___2(M-`$B+/8F$``!-B>@QP+KP84``O@$```#HQ>+__^EP_?__2(G'
MZ"CZ__](BX0D6`$``&1(*P0E*`````^%8@$``$B!Q&@!``!(B=];74%<05U!
M7D%?Z9CD__^_#0```+M'84``Z-GB__]!N%,```!)B<5)B<3IJ/O__P\?A```
M````3(M]`.G8_?__#Q^``````#'V3(G_,<#HY./__XG%A<`/A"_^__^)Q^AC
M^/__28G&2(7`#X@<_O__,=)(C7#VB>_HNN3__[H&````2(VT)!H!``")[^A&
MXO__2(/X!@^%P@```(&\)!H!````0T%##X7@_?__9H&\)!X!``!(10^%T/W_
M_S'228UVSDB-G"0@`0``B>_H9N3__[HH````2(G>B>_H]^'__TB#^"AU=\:$
M)$@!````38GH3(GG,<!HQ&%``+F584``O@$```!!N7!@0`!32,?"_____^@_
MY/__65[I#_[__TB+;0A(A>T/A#/]__](B>_H8^+__TB#^`,/AB']__](C7P%
M_+Z%84``Z(KC__^%P$P/1/WI!_W__^AJX___OXIA0``QP.B>]O__9F8N#Q^$
M```````/'P!5OY-@0`!32(/L&$B+'7:```!D2(L$)2@```!(B40D"#'`2(UT
M)`1D2(LK#[:%L````(B%L0```#'`Z!'G__](A<!T"8`X,0^$4P$``#'`Z'SQ
M__]D2(LK2(GON0,```"Z`0```+[#84``Z#'A__](B<5(A<!T)DB+0!!D2(L[
MNL5A0`!(BS#H1.'__TB+11!(BS#V1@Y`#X4S`0``9$B+.[D#````N@$```"^
MRF%``.CKX/__2(G%2(7`="U(C70D!+]A8$``,<#H@N;__TB)PDB%P`^$U@``
M`$B+11!D2(L[2(LPZ.;@__]D2(L[N@$```"^S&%``.CSW___9$B+.[KA84``
M2(G&Z,+@__]D2(L#2(UT)`2_6&!``,:`L0`````QP.@FYO__2(D%OX$``$B)
MPTB%P'0_OL`!``!(B=_H"N/__XU0`8/Z`78)@_@1#X6'````2(M$)`AD2"L$
M)2@````/A8X```!(@\086UW#9@\?1```2(L]>8$``.C<]___2(D%98$``$B)
MPTB%P'6FOXAB0``QP.@!XO__D(!X`0`/A*[^___IGO[__Y!(BP5!@0``2(LP
M2(M%$$B+..A:Z/__Z1____\/'T0``&1(BSOH9^'__^F__O__B<%(BP41@0``
M2(G:O[!B0`!(BS`QP.BGX?__Z%+A__]FD%532(G[OZ]@0`!(@^P89$B+!"4H
M````2(E$)`@QP$B-="0$Z"CE__](A<!T'`^V$(32#Y3`@/HP#Y3""-!U"DB%
MVW0%@#L`=1=(BT0D"&1(*P0E*````'5F2(/$&%M=PTB)W^@H[O__OB\```!(
MB<=(B<7H..#__TB-4`%(A<!(#T7J2(GOZ*7@__^Z!````+Y[84``2(G'Z-/>
M__^%P'6H2(M$)`AD2"L$)2@```!U#DB#Q!A(B=];7>GQY?__Z(S@__]F+@\?
MA```````9I!!5TB)_DR-1SA!5D%505154TB![)@"``!D2(L$)2@```!(B80D
MB`(``#'`3(V,)(````!(B>=F+@\?A```````08L`28L(2(/'$$F#P`@/R(G`
M2(G*2(E'\$B)R$C!ZB!(P>@H2,'I."4`_P``2`G(2(G12,'B"$C!X1B!X@``
M_P")R4@)R$@)T$B)1_A,.<]UKF8/;T0D$&8/;UPD($B-1"1H2(V4)&@"``!F
M#V]4)#!F#V\MQUT```\?@`````#S#V\(9@]OXF8/;U#82(/`$&8/[T"(9@_O
MRF8/[\%F#V_(9@]ST!]F#W/Q`68/Z\%F#]O%#RE`"&8/;\-F#V_<2#G0=;M,
MBPY,BUX02(M^($B+7AA,B<A,B<I(BVX(2(M,)`A(P>H;2,'@!4@)T`,$)$B-
MC`N9>8):C90XF7F"6DR)V$@QV$@AZ$@QV(T\`DB)ZDB)Z$C!Z`)(P>(>28GZ
M2`G"3(G82<'J&T&)T$PQP$PAR$PQV$@!R$B)^4C!X05,"=%,BU0D$$2-)`A,
MB<A,B<E(P>D"2,'@'D^-E!.9>8):38GE2`G(2<'M&T@QPHG!2"'Z3#'"3`'2
M38GB2<'B!4T)ZDR+;"0800'22(GZ2,'O`DC!XAY%B=)/C80HF7F"6D@)^DV)
MU4@QT(G73"'@2<'M&T@QR$P!P$V)T$G!X`5-">A,BVPD($$!P$R)X$G![`)(
MP>`>18G`2HV,*9EY@EI,">!-B<5(,<))P>T;08G$3"'22#'Z2`'*3(G!2,'A
M!4P)Z4R+;"0H`=%,B=))P>H"2,'B'HG)2HV\+YEY@EI,"=))B<U(,=!)P>T;
M08G23"'`3#'@2`'X2(G/2,'G!4P)[TR+;"0P`<=,B<!)P>@"2,'@'HG_3XVD
M+)EY@EI,"<!)B?U(,<))P>T;08G`2"'*3#'23`'B28G\2<'D!4T)[$R+;"0X
M00'42(G*2,'I`DC!XAY%B>1/C90JF7F"6D@)RDV)Y4@QT$G![1N)T4@A^$PQ
MP$P!T$V)XDG!X@5-">I,BVPD0$$!PDB)^$C![P)(P>`>18G23XV$*)EY@EI(
M"?A-B=5(,<))P>T;B<=,(>)(,<I,`<)-B=!)P>`%30GH3(ML)$A!`=!,B>))
MP>P"2,'B'D6)P$J-C"F9>8):3`GB38G%2#'02<'M&T&)U$PAT$@Q^$@!R$R)
MP4C!X05,">E,BVPD4`'!3(G02<'J`DC!X!Z)R4J-O"^9>8):3`G028G-2#'"
M2<'M&T&)PDPAPDPQXD@!^DB)STC!YP5,">],BVPD6`'73(G"2<'H`DC!XAZ)
M_T^-I"R9>8):3`G"28G]2#'02<'M&T&)T$@AR$PQT$P!X$F)_$G!Y`5-">Q,
MBVPD8$$!Q$B)R$C!X!Y(P>D"18GD3XV4*IEY@EI("<A-B>5(,<))P>T;B<%(
M(?I,,<),`=)-B>))P>(%30GJ3(ML)&A!`=)(B?I(P>\"2,'B'D6)TD^-A"B9
M>8):2`GZ38G52#'02<'M&XG73"'@2#'(3`'`38G02<'@!4T)Z$R+;"1P00'`
M3(G@2<'L`DC!X!Y%B<!*C8PIF7F"6DP)X$V)Q4@QPDG![1M!B<1,(=)(,?I(
M`<I,B<%(P>$%3`GI3(ML)'@!T4R)TDC!XAY)P>H"B<E*C;POF7F"6DP)TDF)
MS4@QT$G![1M!B=),(<!,,>!(`?A(B<](P><%3`GO3(NL)(`````!QTR)P$G!
MZ`)(P>`>B?]/C:0LF7F"6DP)P$F)_4@QPDG![1M!B<!((<I,,=),`>))B?Q)
MP>0%30GL1HTL(DB)RDC!Z0),BZ0DB````$C!XAY("<I/C90BF7F"6DV)[$@Q
MT$G![!N)T4@A^$PQP$P!T$V)ZDG!X@5-">),BZ0DD````$$!PDB)^$C!X!Y(
MP>\"18G23XV$()EY@EI("?A-B=1(,<))P>P;B<=,(>I(,<I,`<)-B=!)P>`%
M30G@18G`3`'"38GH2<'M`DG!X!Y!B=1-">A,BZPDF````$PQP$PAT$J-C"F9
M>8):38GE2#'X2<'M&T@!R$R)X4C!X05,">F)R4@!R$R)T4G!Z@)(P>$>08G%
M3`G138G"18G`23'*1#'23(N4)*````!*C;P7H>O9;DV)ZD@!UTR)ZDG!ZAM(
MP>(%3`G2B=)(`==,B>)(P>(>2<'L`D&)^DP#A"2H````3`GB28G,B<E(`XPD
ML````$DQU$0QX$V-I`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q$R)Z$G!
M[0)(P>`>18G@3`GH28G5B=)(`Y0DN````$DQQ40Q[TR-K#FAZ]EN3(G!3(G'
M2,'O&TC!X05("?F)R4D!S4R)T4G!Z@)(P>$>1(GO3`G128G"B<!),<I%,>).
MC:02H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=1,B<))P>@"2,'B'D6)XDP)
MPDF)R$@#A"3`````B<E),=!(`XPDR````$4QZ$Z-K`"AZ]EN3(G038G02<'H
M&TC!X`5,"<")P$D!Q4B)^$C![P)(P>`>18GH2`GX2(G7B=)(`Y0DT````$@Q
MQT0QYTR-I#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)R4D!S$R)T4G!Z@)(P>$>
M1(GG3`G128G"B<!(`X0DV````$DQRD4QZDZ-K!*AZ]EN2(GZ28GZ2<'J&TC!
MX@5,"=*)TDD!U4R)PDG!Z`)(P>(>18GJ3`G"28G(B<E),=!(`XPDX````$4Q
MX$Z-I`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q$B)^$C![P)(P>`>18G@
M2`GX2(G7B=)(`Y0DZ````$@QQT0Q[TR-K#FAZ]EN3(G!3(G'2,'O&TC!X05(
M"?F)R4D!S4R)T4G!Z@)(P>$>1(GO3`G128G"B<!(`X0D\````$DQRD4QXDZ-
MI!*AZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(P>(>18GB3`G"
M28G(B<E),=!%,>A.C:P`H>O9;DR)T$V)T$C!X`5)P>@;2`.,)/@```!,"<")
MP$D!Q4B)^$C![P)(P>`>18GH2`GX2(G7B=)(`Y0D``$``$@QQT0QYTR-I#FA
MZ]EN3(G!3(G'2,'O&TC!X05("?F)R4D!S$R)T4G!Z@)(P>$>1(GG3`G128G"
MB<!(`X0D"`$``$DQRD4QZDZ-K!*AZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!
MU4R)PDG!Z`)(P>(>18GJ3`G"28G(B<E),=!%,>!.C:0`H>O9;DR)T$V)T$G!
MZ!M(P>`%3`G`2`.,)!`!``")P$D!Q$B)^$C![P)(P>`>18G@2`GX2(G7B=)(
M`Y0D&`$``$@QQT0Q[TR-K#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)R4D!S4R)
MT4G!Z@)(P>$>1(GO3`G128G"B<!(`X0D(`$``$DQRD4QXDZ-I!*AZ]EN2(GZ
M28GZ2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(P>(>18GB3`G"28G(B<E),=!%
M,>A.C:P`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)`<5(B?A(P>`>2,'O`D6)
MZ$@#C"0H`0``2`GX2(G7B=)(`Y0D,`$``$@QQT0QYTV)Q$B-C#FAZ]EN3(G'
M2<'L&TC!YP5,">=-B=1)P>H"2<'D'HG_30G428G"2`'YB<!-,>*)ST@#A"0X
M`0``13'J28G]3HV4$J'KV6Y(B?I)P>T;2,'B!4P)ZD$!TDR)PDG!Z`)(P>(>
M18G23`G"38G@18GD23'028G608G51#'!38G02(V,"*'KV6Y,B=!)P>@;2,'@
M!4P)P$2-!`%(B?E(P>\"N-R\&X](P>$>2`GY20G.B<]((?I-(=9)"=9(BY0D
M0`$``$@!PDP!XDV)Q$P!\DV)QDG!Y`5)P>X;30GT00'43(G22<'J`DC!XAY%
MB>1,"=)("=%)B=9!B=))(?Y,(<%,"?%,B[0D2`$``$D!QDT!]4V)YDP!Z4V)
MY4G![AM)P>4%30GU28G600'-3(G!2<'H`DC!X1Y%B>U,"<%!B<A)"<Y-(>9,
M(<),"?),B[0D4`$``$D!QDP!]TV)[D@!^DR)[TG![AM(P><%3`GW`==,B>))
MP>P"2,'B'HG_3`GB2`G128G608G432'&3"'I3`GQ3(NT)%@!``!)`<9-`?))
MB?Y,`=%)B?I)P>X;2<'B!4T)\DF)UD$!RDR)Z4G![0)(P>$>18G23`GI08G-
M20G.22'^3"'J3`GR3(NT)&`!``!)`<9-`?!-B=9,`<)-B=!)P>`%2<'N&TT)
M\$$!T$B)^DC![P)(P>(>18G`2`GZ2`G128G6B==-(>Y,(=%,"?%,B[0D:`$`
M`$D!QDT!]$V)QDP!X4V)Q$G![AM)P>0%30GT28G600',3(G12<'J`DC!X1Y%
MB>1,"=%!B<I)"<Y-(<9,(=),"?),B[0D<`$``$D!QDT!]4V)YDP!ZDV)Y4G!
M[AM)P>4%30GU00'53(G"2,'B'DG!Z`)%B>U,"<)("=%)B=9!B=!-(=9,(>%,
M"?%,B[0D>`$``$D!QDP!]TV)[D@!^4R)[TG![AM(P><%3`GW28G6`<],B>%)
MP>P"2,'A'HG_3`GA08G,20G.32'N3"'B3`GR3(NT)(`!``!)`<9-`?))B?Y,
M`=))B?I)P>X;2<'B!4T)\D$!TDR)ZDG![0)(P>(>18G23`GJ2`G128G608G5
M2"'Y32'F3`GQ3(NT)(@!``!)`<9-`?!-B=9,`<%-B=!)P>X;2<'@!4T)\$F)
MUD$!R$B)^4C![P)(P>$>18G`2`GYB<])"<Y-(=9((?I,"?),B[0DD`$``$D!
MQDT!]$V)QDP!XDV)Q$G![AM)P>0%30GT00'43(G22<'J`DC!XAY%B>1,"=)(
M"=%)B=9!B=))(?Y,(<%,"?%,B[0DF`$``$D!QDT!]4V)YDP!Z4V)Y4G![AM)
MP>4%30GU28G600'-3(G!2<'H`DC!X1Y%B>U,"<%!B<A)"<Y-(>9,(<),"?),
MB[0DH`$``$D!QDP!]TV)[D@!^DR)[TG![AM(P><%3`GW`==,B>))P>P"2,'B
M'HG_3`GB2`G128G608G432'&3"'I3`GQ3(NT)*@!``!)`<9-`?))B?Y,`=%)
MB?I)P>X;2<'B!4T)\DF)UD$!RDR)Z4G![0)(P>$>18G23`GI08G-20G.22'^
M3"'J3`GR3(NT)+`!``!)`<9-`?!-B=9,`<)-B=!)P>X;2<'@!4T)\$$!T$B)
M^DC![P)(P>(>18G`2`GZ2`G128G6B==-(>Y,(=%,"?%,B[0DN`$``$D!QDT!
M]$V)QDP!X4V)Q$G![AM)P>0%30GT28G600',3(G12<'J`DC!X1Y%B>1,"=%)
M"<Y!B<I-(<9,(=),"?),B[0DP`$``$D!QDT!]4V)YDP!ZDV)Y4G![AM)P>4%
M30GU00'53(G"2<'H`DC!XAY%B>U,"<)("=%)B=!!B==-(=!,(>%,"<%,BX0D
MR`$``$D!P$P!QTV)Z$@!^4R)[TG!Z!M(P><%3`G'1(T$.4R)YTG![`)(B=%(
MP><>3`GG08G\2`GY3"'I3"'B2`G*2(N,)-`!``!(`<%,`=%-B<)(`X0DV`$`
M`$@!RDR)P4G!ZAM(P>$%3`G1B<E(`<I,B>E)P>T"2,'A'D&)TDP)Z4@)STF)
MS4&)SDPAQTTAY4D)_4J-/#A,B=!,B[PD^`$``$P![TV)U4C!X`5)P>T;3`GH
MB<!(`<=,B<!)P>@"2,'@'D&)_4D)P+C6P6+*3#'!,=%(BY0DX`$``$@!PDP!
MXDV)[$@!RDR)Z4G![!M(P>$%3`GA38G4B<E)P>0>2`'*2<'J`DD!QTT)XDV)
MQ(G118G`33'41#'G3(ND).@!``!)`<1-`?1)B<Y,`>=)B<Q)P>X;2<'D!4T)
M]$V)[DG![0))P>8>18GD30GU3(NT)/`!``!,`>=!B?Q)`<9-`?!-B=9-,>Y$
M,?)-B>9)`=!,B>))P>X;2,'B!4P)\HG220'02(G*2,'I`DC!XAY%B<9("<I$
MB=%-B>I),=),`?E,B[PD``(``$0QUTV)\D@!STR)\4C!X05)P>H;20''3`G1
MB<E(`<],B>%)P>P"2,'A'D&)^DD)S$2)Z4F)U8G233'E3`'Y3(N\)!`"``!%
M,>A-B=5)`<A,B=%)P>T;20''2,'A!4P)Z8G)20'(3(GQ2<'N`DC!X1Y%B<5,
M"?%,B[0D"`(``$D!QDP!\DV)YDDQSD0Q]TV)[D@!UTR)ZDG![AM(P>(%3`GR
MB=)(`==,B=))P>H"2,'B'D&)_DD)TD2)XDF)S(G)3`'Z33'43(N\)"`"``!%
M,>!-B?1)`=!,B?))P>P;20''2,'B!4P)XHG220'03(GJ2<'M`DC!XAY%B<1,
M">I,BZPD&`(``$D!Q4P!Z4V)U4DQU40Q[TV)Y4@!STR)X4G![1M(P>$%3`GI
MB<E(`<],B?%)P>X"2,'A'D&)_4D)SD2)T4F)THG233'R3`'Y3(N\)#`"``!%
M,=!-B>I)`<A,B>E)P>H;2,'A!4P)T8G)20'(3(GA2,'A'DG![`)%B<))`<=,
M">%,BZ0D*`(``$D!Q$P!XDV)]$DQS$0QYTV)U$@!UTR)TDG![!M(P>(%3`GB
MB=)(`==,B>I)P>T"2,'B'D&)_$D)U42)\DF)SHG)33'N3`'Z3(N\)$`"``!%
M,?!-B>9)`=!,B>))P>X;2,'B!4P)\HG220'03(G22<'J`DC!XAY%B<9,"=),
MBY0D.`(``$D!PDP!T4V)ZDDQTD0QUTV)\D@!STR)\4C!X05)P>H;20''3`G1
MB<E(`<],B>%)P>P"2,'A'D&)^DD)S$2)Z4F)U8G233'E3`'Y3(N\)&`"``!%
M,>A-B=5)`<A,B=%)P>T;2,'A!4P)Z8G)20'(3(GQ2<'N`DC!X1Y%B<5,"?%,
MB[0D2`(``$D!QDP!\DV)YD6)Y$DQSD0Q]TV)[D@!UTR)ZDG![AM(P>(%3`GR
MB=)(`==,B=))P>H"2,'B'D&)_DD)TDB+E"10`@``2`'"20'42(G*B<E,,=))
M`<=$,<)-B?!)`=1,B?))P>@;2,'B!4P)PHG220'43(GJ2<'M`DC!XAY%B>!,
M">I,BZPD6`(``$D!Q4P!Z4V)U4DQU40Q[TV)Q4@!STR)P4G![1M(P>$%3`GI
MB<E(`<],B?%)P>X"2,'A'D&)_4D)SD2)T4F)THG233'R3`'Y3(N\)'`"``!%
M,>)-B>Q,`=%-B>I)P>P;2<'B!4T)XDV)Q$6)TDG!Y!Y,`=%)P>@"20''30G@
M3(ND)&@"``!!B<I)`<1(`X0D>`(``$P!XDV)]$P!R$TQQ$0QYTV)U$@!UTR)
MTDG![!M(P>(%3`GB38GL2<'M`DG!Y!Z)TDT)Y46)]$V)QD@!UTTQ[HGZ30'\
M18G`1#'Q28G63`'`38GH3`'A28G42<'N&TG!Y`5-"?1$`>%-B=1)P>H"2<'D
M'HG)30GB33'01#''28G(2`'X2(G/2,'G!4G!Z!L!Z4$!VDP)QT0#;B!(B4X(
M`?A,B5882(D&2(G02,'J`DC!X!Y,B6X@2`G01`'82(E&$$B+A"2(`@``9$@K
M!"4H````=1)(@<28`@``6UU!7$%=05Y!7\/H%LK__V8/'T0``$B#[`B_@```
M`.@RR/__9@]O!0I(``!(QT`P``````\1`&8/;P4'2```QT!X``````\10!!F
M#V\%!$@```\10"!(@\0(PV9F+@\?A```````05=(8\)!5DF)QD%5051)B?Q5
M2(UO.%-(B?-(@^P(2(MW*$B+5S"-#,9(.?%(B4\H2(/2`$C!Z!U(`=!(B4<P
M2&-'>(7`#X7M````08/^/P^.*P$``$&#[D!%B?=!P>\&18UO`4G!Y09)`=T/
M'T0``/,/;P-,B>=(@\-`#Q%%`/,/;TO0#Q%-$/,/;U/@#Q%5(/,/;UOP#Q%=
M,.BAZ/__3#GK=<Q!P><&12G^26/&2(/X"')<28M5`$B-30A(@^'X28E4)#A)
MBU0%^$B)5`7X2"G-2`'H22GM2(/@^$B#^`AR&$B#X/@QTDF+=!4`2(DT$4B#
MP@A(.<)R[D6)="1X2(/$"%M=05Q!74%>05_#9I"H!'5T2(7`=.%!#[95`$&(
M5"0XJ`)TTT$/MU0%_F:)5`7^Z\8/'T``0;]`````2(U\!0!(B=Y!*<=%.?=%
M#T_^36/O3(GJZ$7)__]!BT0D>$0!^$&)1"1X@_A`=9),B>=%*?Y,`>OHQ>?_
M_^G+_O__28G=Z2/___]!BU4`08E4)#A!BU0%_(E4!?SI6____Y!!5DR-=CA!
M54%454B)_5-,BVXH2(GS3(MF,$R)Z$C!Z`.#X#^-2`%(F,9$!CB`2&/!3`'P
M@_DX#XZ#`0``OD`````ISG0/,=*)T8/"`<8$"``Y\G+S2(G?Z$/G__]F#^_`
M#Q%#.$G'1C``````00\11A!!#Q%&($R)XD$/ML5,B>],B>Y(P>H82,'@"$R)
MX4C![Q!)B=!,B>I(P>X8#[;60`^V_T`/MO9(P>D02`G03(GB#[;)2,'@"$@)
M^`^V_D$/MM!(P>`(2`GP00^V]$C!X`A("?!(P>`(2`GX2(G?2,'@"$@)R$C!
MX`A("=!(B4-PZ*KF__](BP-(B=](P>@8B$4`2(L#2,'H$(A%`4B+`XAE`DB+
M`XA%`TB+0PA(P>@8B$4$2(M#"$C!Z!"(105(BT,(B&4&2(M#"(A%!TB+0Q!(
MP>@8B$4(2(M#$$C!Z!"(10E(BT,0B&4*2(M#$(A%"TB+0QA(P>@8B$4,2(M#
M&$C!Z!"(10U(BT,8B&4.2(M#&(A%#TB+0R!(P>@8B$402(M#($C!Z!"(11%(
MBT,@B&422(M#((A%$UM=05Q!74%>Z2K%__]F+@\?A```````NC@````Q_RG*
M@_H(<D*)T4C'``````!(QT0(^`````!(C4@(2(/A^$@IR`'"@^+X@_H(#X)^
M_O__@^+X,<")QH/`"$B)/#$YT'+SZ6?^___VP@1U(X72#X1:_O__Q@``]L("
M#X1._O__,<EFB4P0_NE"_O__#Q\`QP``````QT00_`````#I+/[__P\?1```
M2(L-\60``.G$P___2(/L"$B#Q`C#````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@`Q`&QS965K(&9A:6QE9`!R96%D(&9A:6QE
M9`!,1%],24)205)97U!!5$@`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%
M4@!54T523D%-10`E,#)X`"5S)7,E<R5S`'!A<BT`<&%R;``N<&%R`'-H;W)T
M(')E860`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE
M=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#8S`"UE
M`"TM`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*````````56YA8FQE('1O(&-R96%T92!C86-H
M92!D:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A
M8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````````
M`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?
M7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D
M8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2
M+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*
M)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S
M7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*
M;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE
M(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@
M)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@
M;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@
M)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H
M*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?
M34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D
M8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R
M;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I
M<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H
M<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN
M9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL
M("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I5
M3DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64[
M"G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@
M73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M
M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*
M9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P
M,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL
M(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI
M.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F
M:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?
M96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@
M/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE
M*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?
M<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S
M96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@
M>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO
M=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C
M(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA
M<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?
M1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD
M(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE
M(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P
M;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A
M9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B
M7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C
M:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H
M92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,
M15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I
M.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T
M(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@
M+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?
M1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B
M+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B
M=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@
M/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE
M?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M
M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L
M;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@
M7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF
M+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M
M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U
M<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE
M?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII
M9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W
M*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#
M86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD
M9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T
M=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I
M;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@
M/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD
M(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA
M;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H
M)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII
M9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA
M;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^
M("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI
M<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*
M;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]
M("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II
M<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@
M*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@
M)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P
M87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N
M7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=
M(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%
M55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E
M:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=6
M6S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF
M("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@
M*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G
M02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G
M3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L
M92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G
M86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS
M:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE
M('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D
M,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD[
M"FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG
M4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`
M24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T
M.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@
M*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O
M<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE
M<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG
M('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII
M9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY
M;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>
M7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I]
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D
M<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=
M.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I
M<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#
M.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/
M.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI
M(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H
M+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H
M9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D
M;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A
M;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!
M4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2![
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D
M;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O
M=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R
M96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,
M;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI
M8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!8
M6%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D[
M"FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS
M92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<
M421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q
M*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD
M?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D
M,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0[
M"GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D
M=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C
M:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65]
M(#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N
M9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S
M92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT
M+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@
M86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D
M;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE
M;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7
M<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R
M:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO
M<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]
M"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB
M*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C
M='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T
M>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@
M/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A
M8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X]
M(")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M
M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@
M)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L
M;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B
M.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER
M92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U
M:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F
M:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F
M:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH
M*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@
M7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H
M:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@
M>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO
M=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T
M;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X
M="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E
M>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M
M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H
M+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E
M9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I
M;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L
M<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D
M97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H
M)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@
M<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE
M(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"([
M"GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2![
M"F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP
M87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O
M9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`
M05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D
M97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN
M*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H
M)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E
M<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q
M=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R
M:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@
M0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I
M<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER
M92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R
M97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E
M<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@
M871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U
M:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE
M=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![
M(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E
M<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@
M>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY
M("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2
M(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI
M('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD
M("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P
M=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E
M9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN
M,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S
M97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U53
M15).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP
M9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U
M<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER
M.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD
M)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM
M>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L
M96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E
M96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG
M=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H
M+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C
M86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@
M*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[
M4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C
M86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-
M4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`
M7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H
M+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B
M.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H
M<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L
M("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE
M+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D
M9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O
M*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*
M:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[
M4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA
M;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II
M9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S
M>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R
M;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA
M;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T
M=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?
M<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!
M4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S
M+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@
M+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?
M<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!
M345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@
M>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@
M)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I
M"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H
M*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<
M+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E
M;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E
M='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF
M;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!
M344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-
M4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D
M14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"
M04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[
M4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*
M:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP
M<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I
M9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF
M:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP
M('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP
M86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2
M.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A
M<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@
M<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE
M.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/
M4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@
M)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``$-!0TA%``!P97)L>'-I+F,`````
M````5F!```````!384```````%MA0```````9&%```````#_____`````/__
M__\``````2-%9P````")J\WO`````/[<NI@`````=E0R$`````#PX=+#````
M`````````````1L#._P````>````0'___U@!``#0@O__K`4``-"$__\8`0``
M`(7__T0!``#`A?__@`$``)"&___,`0``((?___`!``"0B/__+`(``&")__]@
M`@``H(O__ZP"``#@B___R`(```",___<`@``P(S__P`#``#0C/__%`,``-".
M__]D`P```(___X`#``!`D/__N`,``)"4___4`P```)7___`#``#`E?__"`0`
M`."6__]`!````)?__U@$``#0E___F`0``'">__](!0``<*#__W0%``!`H?__
MT`4``+"W__\@!@```+C__S@&``"@N?__A`8``/"[___(!@```````!0`````
M`````7I2``%X$`$;#`<(D`$'$!`````<````L(/__R(`````````%```````
M```!>E(``7@0`1L,!PB0`0``$````!P```"T@___`0`````````D````,```
M`.!]__^0`P````X01@X82@\+=PB``#\:.RHS)"(`````2````%@````XA/__
MS`````!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P=$#D`";`H..$0.
M,$$.*$(.($(.&$(.$$(."$D+`"````"D````O(3__X,`````00X0@P)*#K`!
M`G$*#A!!#@A!"S@```#(````*(7__V0!````0@X0C0)"#AB,`T$.((8$00XH
M@P5'#M`!?@H.*$$.($$.&$(.$$(."$<+`#`````$`0``7(;__\@`````0@X0
MC`)&#AB&`T0.((,$3PZP(`)A"@X@00X800X00@X(2`M(````.`$``/B&__\Q
M`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9$#CB#!T<.4`,5`0H..$$.
M,$$.*$(.($(.&$(.$$(."$4+&````(0!``#LB/__0`````!!#A"#`F<."```
M`!````"@`0``$(G__Q\`````````(````+0!```<B?__LP````!!#A"#`D<.
ML$`"G0H.$$0."$$+$````-@!``"XB?__!0````````!,````[`$``+2)____
M`0```$(.$(T"0@X8C`-)#B"&!$$.*(,%2@[@(0)B"@XH00X@00X80@X00@X(
M2`L"D0[H(4X.\"%N#N@A00[@(0```!@````\`@``9(O__R(`````00X0@P)<
M#@@````T````6`(``'B+__\Q`0```$$.$(8"00X8@P-'#K`@`N$*#AA!#A!!
M#@A$"UH*#AA&#A!!#@A/"Q@```"0`@``@(S__T8$````1`X@`Q$$"@X(10L8
M````K`(``+20__]A`````$0.(`)."@X(1@L`%````,@"```(D?__L@````!'
M#N`!````-````.`"``"PD?__&@$```!"#A",`DL.&(8#00X@@P1'#K"`!`+`
M"@X@00X800X00@X(1PL````4````&`,``)B2__\=`````$0.$%@."``\````
M,`,``*"2___%`````$(.$(P"00X8A@-)#B"#!$0.,'X*#B!(#AA!#A!"#@A'
M"V$..$D.0&`..$$.,```K````'`#```PD___D@8```!"#A"/`D(.&(X#0@X@
MC01"#BB,!4$.,(8&20XX@P='#J`#`\\!#J@#3@ZP`VP.J`-"#J`#`FT*#CA$
M#C!!#BA"#B!"#AA"#A!"#@A""P,P`0ZH`T<.L`-?#J@#00Z@`U\.J`-(#K`#
M3PZX`TT.P`-+#J`#`N$*#CA$#C!!#BA"#B!"#AA"#A!"#@A%"P+L#J@#40ZP
M`TT.J`-!#J`#```H````(`0``""9___^`0```$$.$(8"1@X8@P-$#C`#9`$*
M#AA!#A!!#@A'"S0```!,!```])K__\0`````00X0A@)!#AB#`TP.,`)/"@X8
M00X000X(00L"50H.&$0.$$$."$4+(````(0$```<??__]`$```!!#A"#`D0.
M0`-7`0H.$$,."$$+3````*@$``!HF___:A8```!"#A"/`DD.&(X#0@X@C01"
M#BB,!4$.,(8&00XX@P='#M`%`T(6"@XX00XP00XH0@X@0@X80@X00@X(00L`
M```4````^`0``(BQ__]%`````$0.$`)`#@A(````$`4``,"Q__^?`0```$(.
M$(\"10X8C@-%#B"-!$(.*(P%1`XPA@9%#CB#!T<.0`+E"@XX00XP00XH0@X@
M0@X80@X00@X(0PL`0````%P%```4L___2P(```!"#A".`D8.&(T#0@X@C`1!
M#BB&!40.,(,&`YL!"@XH00X@0@X80@X00@X(3PL````````0````H`4``""U
M__\,````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````)`F0```````8"9````````!`````````)D"`````````0``````
M``"I`@````````P``````````"!````````-`````````-Q<0```````&0``
M``````#@O4```````!L`````````"``````````:`````````.B]0```````
M'``````````(`````````/7^_V\`````P`-````````%`````````!@*0```
M````!@`````````8!$````````H``````````@,````````+`````````!@`
M````````%0````````````````````,`````````Z+]````````"````````
M`$`%````````%``````````'`````````!<`````````L`Y````````'````
M`````"`.0```````"`````````"0``````````D`````````&`````````#^
M__]O`````*`-0```````____;P`````!`````````/#__V\`````&@U`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#PO4``````````````
M```````````````V($```````$8@0```````5B!```````!F($```````'8@
M0```````AB!```````"6($```````*8@0```````MB!```````#&($``````
M`-8@0```````YB!```````#V($````````8A0```````%B%````````F(4``
M`````#8A0```````1B%```````!6(4```````&8A0```````=B%```````"&
M(4```````)8A0```````IB%```````"V(4```````,8A0```````UB%`````
M``#F(4```````/8A0```````!B)````````6(D```````"8B0```````-B)`
M``````!&(D```````%8B0```````9B)```````!V(D```````(8B0```````
MEB)```````"F(D```````+8B0```````QB)```````#6(D```````.8B0```
M````]B)````````&(T```````!8C0```````)B-````````V(T```````$8C
M0```````5B-```````!F(T```````'8C0```````AB-```````"6(T``````
M`*8C0`````````````````````````````I005(N<&T*``````````#X8D``
M`````$=#0SH@*$UA9V5I82`Q,BXS+C`M,RYM9V$Y*2`Q,BXS+C```"YS:'-T
M<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YP<F]P97)T>0`N;F]T92YG;G4N8G5I
M;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R
M`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N
M<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N
M96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O
M=``N9V]T+G!L=``N9&%T80`N8G-S`"YC;VUM96YT````````````````````
M````````````````````````````````````````````````````````````
M````````````````"P````$````"`````````!@#0```````&`,````````<
M`````````````````````0```````````````````!,````'`````@``````
M```X`T```````#@#````````0`````````````````````@`````````````
M```````F````!P````(`````````>`-```````!X`P```````"0`````````
M```````````$````````````````````.0````<````"`````````)P#0```
M````G`,````````@````````````````````!````````````````````$<`
M``#V__]O`@````````#``T```````,`#````````6``````````&````````
M``@```````````````````!1````"P````(`````````&`1````````8!```
M```````&````````!P````$````(`````````!@`````````60````,````"
M`````````!@*0```````&`H````````"`P```````````````````0``````
M`````````````&$```#___]O`@`````````:#4```````!H-````````@```
M```````&``````````(``````````@````````!N````_O__;P(`````````
MH`U```````"@#0```````(``````````!P````$````(````````````````
M````?0````0````"`````````"`.0```````(`X```````"0``````````8`
M````````"``````````8`````````(<````$````0@````````"P#D``````
M`+`.````````0`4````````&````%P````@`````````&`````````"1````
M`0````8``````````"!`````````(````````!<````````````````````$
M````````````````````C`````$````&`````````"`@0```````("``````
M``"0`P``````````````````$``````````0`````````)<````!````!@``
M``````"P(T```````+`C````````+#D``````````````````!``````````
M``````````"=`````0````8`````````W%Q```````#<7`````````D`````
M```````````````$````````````````````HP````$````"``````````!@
M0````````&````````#@0```````````````````$```````````````````
M`*L````!`````@````````#@H$```````."@````````_```````````````
M``````0```````````````````"Y`````0````(`````````X*%```````#@
MH0```````.`%```````````````````(````````````````````PP````X`
M```#`````````."]0```````X*T````````(````````````````````"```
M```````(`````````,\````/`````P````````#HO4```````.BM````````
M"`````````````````````@`````````"`````````#;````!@````,`````
M````\+U```````#PK0```````.`!````````!P`````````(`````````!``
M````````Y`````$````#`````````-"_0```````T*\````````8````````
M````````````"``````````(`````````.D````!`````P````````#HOT``
M`````.BO````````V`$```````````````````@`````````"`````````#R
M`````0````,`````````P,%```````#`L0```````"@`````````````````
M```(````````````````````^`````@````#``````````#"0```````Z+$`
M``````!8````````````````````(````````````````````/T````!````
M,````````````````````.BQ````````(P````````````````````$`````
M`````0`````````!`````P`````````````````````````+L@````````8!
>```````````````````!````````````````````
